
[![PyPI status](https://img.shields.io/pypi/status/dpytools.svg)](https://pypi.python.org/pypi/dpytools/)
[![PyPI version fury.io](https://badge.fury.io/py/dpytools.svg)](https://pypi.python.org/pypi/dpytools/)
[![PyPI license](https://img.shields.io/pypi/l/dpytools.svg)](https://pypi.python.org/pypi/dpytools/)


# dpytools
Toolset to speed up developing discord bots using discord.py

<hr>

## Status of the project

Early development. As such it's expected to be unstable and unsuited for production.

All the presented tools have stringdocs.
<hr>

# Instalation
Install the latest version of the library with pip.
```
pip install -U dpytools
```

# Contributing
Feel free to make a pull request.